Adding more doxygen documentation
diff --git a/helper/ccnb-parser/syntax-tree/ccnb-parser-blob.h b/helper/ccnb-parser/syntax-tree/ccnb-parser-blob.h
index f2ede3d..195c84c 100644
--- a/helper/ccnb-parser/syntax-tree/ccnb-parser-blob.h
+++ b/helper/ccnb-parser/syntax-tree/ccnb-parser-blob.h
@@ -52,7 +52,7 @@
   virtual boost::any accept( Visitor &v, boost::any param ) { return v.visit( *this, param ); }
 
   char* m_blob; ///< \brief field holding a parsed BLOB value of the block
-  uint32_t  m_blobSize;
+  uint32_t  m_blobSize; ///< @brief field representing size of the BLOB field stored
 };
 
 }
diff --git a/helper/ccnb-parser/syntax-tree/ccnb-parser-block.cc b/helper/ccnb-parser/syntax-tree/ccnb-parser-block.cc
index 29e3fac..805582a 100644
--- a/helper/ccnb-parser/syntax-tree/ccnb-parser-block.cc
+++ b/helper/ccnb-parser/syntax-tree/ccnb-parser-block.cc
@@ -35,10 +35,12 @@
 namespace ns3 {
 namespace CcnbParser {
 
+/// @cond include_hidden
 const uint8_t CCN_TT_BITS = 3;
 const uint8_t CCN_TT_MASK = ((1 << CCN_TT_BITS) - 1);
 const uint8_t CCN_MAX_TINY= ((1 << (7-CCN_TT_BITS)) - 1);
 const uint8_t CCN_TT_HBIT = ((uint8_t)(1 << 7));
+/// @endcond
 
 // int Block::counter = 0;
 
diff --git a/helper/ccnb-parser/syntax-tree/ccnb-parser-block.h b/helper/ccnb-parser/syntax-tree/ccnb-parser-block.h
index 9538a1f..6ea5fba 100644
--- a/helper/ccnb-parser/syntax-tree/ccnb-parser-block.h
+++ b/helper/ccnb-parser/syntax-tree/ccnb-parser-block.h
@@ -59,13 +59,17 @@
 
   virtual ~Block ();
   
-  virtual void accept( VoidNoArguVisitor &v )               = 0;
-  virtual void accept( VoidVisitor &v, boost::any param )   = 0;
-  virtual boost::any accept( NoArguVisitor &v )             = 0;
-  virtual boost::any accept( Visitor &v, boost::any param ) = 0;
+  virtual void accept( VoidNoArguVisitor &v )               = 0; ///< @brief Accept visitor void(*)()
+  virtual void accept( VoidVisitor &v, boost::any param )   = 0; ///< @brief Accept visitor void(*)(boost::any)
+  virtual boost::any accept( NoArguVisitor &v )             = 0; ///< @brief Accept visitor boost::any(*)()
+  virtual boost::any accept( Visitor &v, boost::any param ) = 0; ///< @brief Accept visitor boost::any(*)(boost::any)
 };
 
 // Necessary until Buffer::Iterator gets PeekU8 call
 inline
 uint8_t
 BufferIteratorPeekU8 (Buffer::Iterator &i)
@@ -59,13 +59,17 @@
 };
 
-// Necessary until Buffer::Iterator gets PeekU8 call
+/**
+ * @brief Necessary until Buffer::Iterator gets PeekU8 call
+ * @param i buffer iterator
+ * @return peeked uint8_t value
+ */
 inline
 uint8_t